@@ -10,15 +10,17 @@ use Moose::Role;
 
 around 'command_usage_header' => sub {
     my ($orig,$self) = @_;
-    
+
     my $caller = $self->app_base;
-    
+
     my $usage;
+    # Get usage from command if available
     if ($self->can('command_usage')
         && $self->command_usage_predicate) {
         $usage = MooseX::App::Utils::format_text($self->command_usage);
     }
-    
+
+    # Autobuild usage
     unless ($usage) {
         my $command = $caller;
         my @parameter= $self->command_usage_attributes($self,'parameter');
@@ -32,10 +34,11 @@ around 'command_usage_header' => sub {
         $usage = MooseX::App::Utils::format_text("$command [long options...]
 $caller --help")
     }
-    
+
     return $self->command_message(
         header  => 'usage:',
-        body    => $usage); # LOCALIZE
+        body    => $usage
+    ); # LOCALIZE
 };
 
 1;
\ No newline at end of file
