@@ -9,13 +9,10 @@ use namespace::autoclean;
 use Moose::Role;
 use MooseX::App::Role;
 
-use MooseX::Types::Path::Class;
 use Config::Any;
 
 has 'config' => (
     is              => 'ro',
-    isa             => 'Path::Class::File',
-    coerce          => 1,
     predicate       => 'has_config',
     documentation   => q[Path to command config file],
     traits          => ['MooseX::App::Meta::Role::Attribute::Option'],
@@ -97,4 +94,4 @@ The full content of the loaded config file
 
 L<Config::Any>
 
-=cut
\ No newline at end of file
+=cut
